package org.jharks.workflow.survey.engine.cache;

import net.sf.ehcache.Cache;
import net.sf.ehcache.CacheException;
import net.sf.ehcache.Element;

import org.apache.log4j.Logger;
import org.jharks.workflow.survey.engine.model.QuestionGroupConfiguration;
import org.springframework.dao.DataRetrievalFailureException;


/**
 * Caches <code>QuestionGroupConfiguration</code> objects using a Spring 
 * IoC defined <AHREF="http://ehcache.sourceforge.net">EHCACHE</a>.
 * 
 * @author Michael J. Rizzo
 */
public class EhCacheBasedQuestionGroupCache implements
        DynamicQuestionGroupCache {

    /** The logger instance for this class. */
    private static final Logger logger = Logger.getLogger(
            EhCacheBasedQuestionGroupCache.class);
    
    /** The cache. */
    private Cache cache;
    
    public QuestionGroupConfiguration getConfigurationFromCache(
            String questionGroup) {
        Element element = null;

        try {
            element = cache.get(questionGroup);
        } catch (CacheException cacheException) {
            throw new DataRetrievalFailureException("Cache failure: " 
                    + cacheException.getMessage());
        }

        if (logger.isDebugEnabled()) {
            logger.debug("Cache hit: " + (element != null) + "; " +
                    "question group: " + questionGroup);
        }

        if (element == null) {
            return null;
        } else {
            return (QuestionGroupConfiguration) element.getValue();
        }
    }

    public void putConfigurationInCache(QuestionGroupConfiguration configuration) {
        Element element = new Element(configuration.getQuestionGroupName(), configuration);

        if (logger.isDebugEnabled()) {
            logger.debug("Cache put: " + element.getKey());
        }

        cache.put(element);
    }

    public void removeConfigurationFromCache(String questionGroup) {
        cache.remove(questionGroup);
    }
    
    /**
     * Setter for cache instance.
     * @param cache the cache to inject.
     */
    public void setCache(Cache cache) {
        this.cache = cache;
    }
}
