package org.jharks.workflow.survey.engine.cache;

import net.sf.ehcache.Cache;
import net.sf.ehcache.CacheException;
import net.sf.ehcache.Element;

import org.apache.log4j.Logger;
import org.jharks.workflow.survey.util.CustomDbResourceBundle;
import org.springframework.dao.DataRetrievalFailureException;

/**
 * Caches <code>CustomDbResourceBundle</code> objects using a Spring
 * IoC defined <AHREF="http://ehcache.sourceforge.net">EHCACHE</a>.
 * 
 * @author Michael J. Rizzo
 */
public class EhCacheBasedResourceBundleCache implements
		WorkFlowResourceBundleCache {

	/** The logger instance for this class. */
	private static final Logger LOGGER = Logger.getLogger(EhCacheBasedResourceBundleCache.class);
	
	/** The underlying cache implementation. */
	private Cache cache;
	
	/**
	 * {@inheritDoc}
	 */
	public CustomDbResourceBundle getBundleFromCache(
			WorkFlowResourceBundleCacheKey bundleKey) {
		
		Element element = null;
		
		try {
			element = cache.get(bundleKey);
		} catch (CacheException cacheException) {
            throw new DataRetrievalFailureException("Cache failure: " 
                    + cacheException.getMessage());
        }
		
		if (LOGGER.isDebugEnabled()) {
            LOGGER.debug("Cache hit: " + (element != null) + "; " +
                    "WorkFlowResourceBundleCacheKey = " + bundleKey.toString());
        }

        if (element == null) {
            return null;
        } else {
            return (CustomDbResourceBundle) element.getValue();
        }

	}

	/**
	 * {@inheritDoc}
	 */
	public void putBundleInCache(CustomDbResourceBundle bundle) {
		
		WorkFlowResourceBundleCacheKey key = new WorkFlowResourceBundleCacheKey(bundle.getBundleName(),
				bundle.getCountryCode(), bundle.getLanguageCode(), bundle.getVariantCode());
		
		Element element = new Element(key, bundle);
		
		 if (LOGGER.isDebugEnabled()) {
	            LOGGER.debug("Cache put: " + element.getKey());
		 }
		 
		 cache.put(element);

	}

	/**
	 * {@inheritDoc}
	 */
	public void removeBundleFromCache(CustomDbResourceBundle bundle) {
		WorkFlowResourceBundleCacheKey key = new WorkFlowResourceBundleCacheKey(bundle.getBundleName(),
				bundle.getCountryCode(), bundle.getLanguageCode(), bundle.getVariantCode());
		
		cache.remove(key);
	}

	/**
     * Setter for cache instance.
     * @param cache the cache to inject.
     */
    public void setCache(Cache cache) {
        this.cache = cache;
    }
	
}
