package org.jharks.workflow.survey.engine.cache;

import java.io.Serializable;

public class WorkFlowResourceBundleCacheKey implements Serializable {

	private static final long serialVersionUID = 1L;
	
	private String bundleName;
	
	private String countryCode;
	
	private String languageCode;
	
	private String variantCode;

	/**
	 * Constructor to populate all fields of cache key.
	 * @param bundleName the name of the bundle.
	 * @param countryCode the country code.
	 * @param languageCode the language code.
	 * @param variantCode the variant code if exists.
	 */
	public WorkFlowResourceBundleCacheKey(String bundleName,
			String countryCode, String languageCode, String variantCode) {
		super();
		this.bundleName = bundleName;
		this.countryCode = countryCode;
		this.languageCode = languageCode;
		this.variantCode = variantCode;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode() {
		final int prime = 37;
		int result = 17;
		result = prime * result
				+ ((bundleName == null) ? 0 : bundleName.hashCode());
		result = prime * result
				+ ((countryCode == null) ? 0 : countryCode.hashCode());
		result = prime * result
				+ ((languageCode == null) ? 0 : languageCode.hashCode());
		result = prime * result
				+ ((variantCode == null) ? 0 : variantCode.hashCode());
		return result;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (!(obj instanceof WorkFlowResourceBundleCacheKey)) {
			return false;
		}
		WorkFlowResourceBundleCacheKey other = (WorkFlowResourceBundleCacheKey) obj;
		if (bundleName == null) {
			if (other.bundleName != null) {
				return false;
			}
		} else if (!bundleName.equals(other.bundleName)) {
			return false;
		}
		if (countryCode == null) {
			if (other.countryCode != null) {
				return false;
			}
		} else if (!countryCode.equals(other.countryCode)) {
			return false;
		}
		if (languageCode == null) {
			if (other.languageCode != null) {
				return false;
			}
		} else if (!languageCode.equals(other.languageCode)) {
			return false;
		}
		if (variantCode == null) {
			if (other.variantCode != null) {
				return false;
			}
		} else if (!variantCode.equals(other.variantCode)) {
			return false;
		}
		return true;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("WorkFlowResourceBundleCacheKey [bundleName=");
		builder.append(bundleName);
		builder.append(", countryCode=");
		builder.append(countryCode);
		builder.append(", languageCode=");
		builder.append(languageCode);
		builder.append(", variantCode=");
		builder.append(variantCode);
		builder.append("]");
		return builder.toString();
	}
	
	/**
	 * @return the bundleName
	 */
	public String getBundleName() {
		return bundleName;
	}

	/**
	 * @return the countryCode
	 */
	public String getCountryCode() {
		return countryCode;
	}

	/**
	 * @return the languageCode
	 */
	public String getLanguageCode() {
		return languageCode;
	}

	/**
	 * @return the variantCode
	 */
	public String getVariantCode() {
		return variantCode;
	}	
}
