package org.jharks.workflow.survey.engine.dao;

import java.util.Collection;

import org.jharks.workflow.survey.engine.model.Question;
import org.jharks.workflow.survey.engine.model.QuestionGroupConfiguration;

/**
 * Defines question Dao API.
 * 
 * @author Michael J. Rizzo
 *
 */
public interface QuestionDao {
    
    /**
     * Populates the map of question ids to alias question keys as defined in 
     * the data store.
     */
    public void populateQuestionIds();
    
    /**
     * Return the system generated question id for the passed question key 
     * (alias text identifier).
     * @param questionKey the question key to look up.
     * @return the question id or null if a question is not found for the passed
     *         key.
     */
    public Long getQuestionId(String questionName);
    
    /**
     * Returns the set of questions that are mapped to the passed group id.  The
     * group represents any form of page grouping such as a page.
     * @param groupId the group id for which to retrieve mapped questions.
     * @return the set of questions that are contained within the passed group 
     *         id.
     */
    public Collection<Question> getQuestionsByGroup(String groupId);
    
    /**
     * Returns the question group configuration for the passed group id.
     * @param groupId the group id for which to retrieve the configuration item.
     * @return the configuration object for the passed group id.
     */
    public QuestionGroupConfiguration getQuestionGroupConfiguration(String groupId);
    
    /**
     * Method for retrieval of pre-cached question ids by <code>
     * PersistenceManager</code>.
     * @param questionKey the question key to look up.
     * @return the question id or null if a question is not found for the passed
     *         key.
     */
    public Long getLoadedQuestionId(String questionKey);
}
