package org.jharks.workflow.survey.engine.dao;

import java.sql.Connection;
import java.util.ResourceBundle;

import org.jharks.workflow.SessionHistory;
import org.jharks.workflow.survey.engine.model.GroupAnswers;
import org.jharks.workflow.survey.engine.model.GroupBasedAnswerSet;

public interface ResponseDao {
    
    /**
     * Retrieves all persisted answers for specified group and groups responses
     * by database configured group names and restricts to those question groups
     * mapped to a core measure (quality type). This method will return 
     * non-localized answer group keys in the returned object structure. 
     * @param surveyId the identifier of the survey record.
     * @return all answers organized by groups.
     */
    public GroupBasedAnswerSet getResponsesSummary(Long surveyId);
    
    /**
     * Retrieves all persisted answers for specified group and groups responses
     * by database configured group names and restricts to those question groups
     * mapped to a core measure (quality type).
     * @param surveyId the identifier of the survey record.
     * @param localizeAnswerGroups indicates whether the answer group should be 
     *        localized or left as question group code.
     * @param bundle the resource bundle to be used for localization.
     * @return all answers organized by groups.
     */
    public GroupBasedAnswerSet getResponsesSummary(Long surveyId, 
            boolean localizeAnswerGroups, ResourceBundle bundle);
    
    
    /**
     * Retrieves all persisted answers for a specified page group and organizes
     * into a group answers structure.
     * @param pageGroup the page group fro which to retireve answers.
     * @param sesionHistorySnapshot a history snapshot retrieved from memory.
     * @return answers organized in a <code>GroupAnswers</code> instance.
     */
    public GroupAnswers getResponsesForPageGroup(String pageGroup, SessionHistory sessionHistorySnapshot);
    
    /**
     * Retrieves all persisted answers for a specified page group and organizes
     * into a group answers structure.
     * @param pageGroup the page group fro which to retireve answers.
     * @param surveyId the survey identifier.
     * @return answers organized in a <code>GroupAnswers</code> instance.
     */
    public GroupAnswers getResponsesForPageGroup(String pageGroup, Long surveyId);
    
    /**
     * Retrieves all persisted answers for a specified page group and organizes
     * into a group answers structure.
     * @param pageGroup the page group fro which to retireve answers.
     * @param surveyId the survey identifier.
     * @param conn a pre-fetched database connection.
     * @return answers organized in a <code>GroupAnswers</code> instance.
     */
    public GroupAnswers getResponsesForPageGroup(String pageGroup, Long surveyId, Connection conn);
    
}
