package org.jharks.workflow.survey.engine.dao.impl;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;
import java.util.Properties;

import org.apache.log4j.Logger;
import org.jharks.workflow.survey.engine.cache.WorkFlowResourceBundleCacheKey;
import org.jharks.workflow.survey.engine.dao.WorkFlowResourceBundleDao;
import org.jharks.workflow.survey.util.CustomDbResourceBundle;
import org.springframework.dao.DataAccessException;
import org.springframework.jdbc.core.ResultSetExtractor;

/**
 * @author Michael J. Rizzo
 *
 */
public class WorkFlowResourceBundleJdbcDaoImpl extends AbstractJdbcDaoImpl implements
		WorkFlowResourceBundleDao {

	/** The logger instance for this class. */
	private static final Logger LOGGER = Logger.getLogger(WorkFlowResourceBundleJdbcDaoImpl.class);
	
	/** SQL String used for retrieving a WorkFlow Resource Bundle. */
	private static final String WORKFLOW_BUNDLE_RETRIEVAL = "SELECT RESOURCE_KEY, RESOURCE_VALUE FROM " +
	        DATABASE_SCHEMA + "WORKFLOW_RESOURCE_BUNDLE WHERE BUNDLE = ? AND COUNTRY_CODE = ? AND " +
	        "LANGUAGE_CODE = ? ";
	
	/**
	 * {@inheritDoc}
	 */
	public CustomDbResourceBundle getWorkFlowResourceBundle(
			WorkFlowResourceBundleCacheKey resourceBundleKey) {
		
		if (LOGGER.isDebugEnabled())
			LOGGER.debug("Attempting to build ResourceBundle for baseName = [ " +
					resourceBundleKey.getBundleName() + " ]" +
					" country code = [ " + resourceBundleKey.getCountryCode() + " ]" +
					" language code = [ " + resourceBundleKey.getLanguageCode() + " ]" +	
					" variant code = [ " + resourceBundleKey.getVariantCode() + " ]"
			);
		
		Properties properties = null;
		if (resourceBundleKey.getVariantCode() == null) {
			properties = (Properties) this.getJdbcTemplate().query(WORKFLOW_BUNDLE_RETRIEVAL, new String[] {resourceBundleKey.getBundleName(), 
				resourceBundleKey.getCountryCode(),
				resourceBundleKey.getLanguageCode()}, new int[] {Types.VARCHAR, Types.VARCHAR, Types.VARCHAR}, new PropertiesResultSetExtractor() );
		} else {
			properties = (Properties) this.getJdbcTemplate().query(WORKFLOW_BUNDLE_RETRIEVAL.concat(" AND VARIANT_CODE = ?"), new String[] {resourceBundleKey.getBundleName(), 
					resourceBundleKey.getCountryCode(),
					resourceBundleKey.getLanguageCode(),
					resourceBundleKey.getVariantCode()}, new int[] {Types.VARCHAR, Types.VARCHAR, Types.VARCHAR, Types.VARCHAR}, new PropertiesResultSetExtractor() );
		}
		
		CustomDbResourceBundle bundle = null;
		if (properties.size() > 0) {
			
		  bundle = new CustomDbResourceBundle(resourceBundleKey.getBundleName(),
				resourceBundleKey.getCountryCode(),
				resourceBundleKey.getLanguageCode(),
				resourceBundleKey.getVariantCode(),
				properties);
		  
		}
		
		return bundle;
	}
	
	private static final class PropertiesResultSetExtractor implements ResultSetExtractor {
		
		public Properties extractData(ResultSet resultSet) throws SQLException, DataAccessException {
		    Properties properties = new Properties();
		    
		    while (resultSet.next()) {
		    	properties.put(resultSet.getString("RESOURCE_KEY"), resultSet.getString("RESOURCE_VALUE"));
		    }
		    return properties;
		}	
	}
}
