package org.jharks.workflow.survey.engine.dto;

/**
 * Data Transfer object that carries metadata from result record.  Carries information about the 
 * question group, answer and exisitng subquestion group and subquestion response set if present. 
 * 
 * @author Michael J. Rizzo
 */
public class QuestionAnswerSubquestionPairDto {

	/** The answer response set id. */
	private Long answerResponseSetId;
	
	/** The question group id. */
	private Long questionGroupId;
	
	/** The question group name. */
	private String questionGroup;
	
	/** The question sequuence within the group. */
	private Integer questionSequence;
	
	/** The question key. */
	private String questionKey;
	
	/** The question id. */
	private Long questionId;
	
	/** The answer choice id. */
	private Long answerChoiceId;
	
	/** The answer choice sequence. */
	private Integer answerChoiceSequence;
	
	/** The answer id of this record. */
	private Long answerId;
	
	/** The corresponding answer key if present. */
	private String answerKey;
	
	/** The subquestion group id of the answer choice if present. */
	private Long subquestionGroupId;
	
	/** The subquestion reponse set id. */
	private Long subquestionResponseSetId;

	/**
	 * Return the answer response set id. 
	 * @return the answer set response set id. 
	 */
	public Long getAnswerResponseSetId() {
		return answerResponseSetId;
	}

	/**
	 * Set the answer response set id
	 * @param answerResponseSetId the id to set.
	 */
	public void setAnswerResponseSetId(Long answerResponseSetId) {
		this.answerResponseSetId = answerResponseSetId;
	}

	/**
	 * Return the question group id. 
	 * @return the question group id.
	 */
	public Long getQuestionGroupId() {
		return questionGroupId;
	}

	/**
	 * Set the question group id. 
	 * @param questionGroupId the question group if to set.
	 */
	public void setQuestionGroupId(Long questionGroupId) {
		this.questionGroupId = questionGroupId;
	}

	/**
	 * Return the question group name.
	 * @return the question group name.
	 */
	public String getQuestionGroup() {
		return questionGroup;
	}

	/**
	 * Set the question group name.
	 * @param questionGroup the question group name to set.
	 */
	public void setQuestionGroup(String questionGroup) {
		this.questionGroup = questionGroup;
	}

	/**
	 * Return the question sequence.
	 * @return the sequence of the question within the group.
	 */
	public Integer getQuestionSequence() {
		return questionSequence;
	}

	/**
	 * Set the question sequence.
	 * @param questionSequence the sequenc to set.
	 */
	public void setQuestionSequence(Integer questionSequence) {
		this.questionSequence = questionSequence;
	}

	/**
	 * Return the question key.
	 * @return the question key.
	 */
	public String getQuestionKey() {
		return questionKey;
	}

	/**
	 * Set the question key.
	 * @param questionKey the question key to set.
	 */
	public void setQuestionKey(String questionKey) {
		this.questionKey = questionKey;
	}

	/**
	 * Return the question id.
	 * @return the question id.
	 */
	public Long getQuestionId() {
		return questionId;
	}

	/**
	 * Set the question id.
	 * @param questionId the question id to set.
	 */
	public void setQuestionId(Long questionId) {
		this.questionId = questionId;
	}

	/**
	 * Return the answer choice id.
	 * @return the answer choice id.
	 */
	public Long getAnswerChoiceId() {
		return answerChoiceId;
	}

	/**
	 * Set the answer choice id.
	 * @param answerChoiceId the answer choice if to set.
	 */
	public void setAnswerChoiceId(Long answerChoiceId) {
		this.answerChoiceId = answerChoiceId;
	}

	/**
	 * Return the sequence of the answer choice within the answer choices for the question.
	 * @return the answer choice sequence.
	 */
	public Integer getAnswerChoiceSequence() {
		return answerChoiceSequence;
	}

	/**
	 * Set the answer choice sequence id.
	 * @param answerChoiceSequence the answer choice sequence.
	 */
	public void setAnswerChoiceSequence(Integer answerChoiceSequence) {
		this.answerChoiceSequence = answerChoiceSequence;
	}

	/**
	 * Return the answer id.
	 * @return the answer id.
	 */
	public Long getAnswerId() {
		return answerId;
	}

	/**
	 * Set the answer id.
	 * @param answerId the answer id to set.
	 */
	public void setAnswerId(Long answerId) {
		this.answerId = answerId;
	}

	/**
	 * Return the corresponding answer key for the answer if present. 
	 * @return the answer key.
	 */
	public String getAnswerKey() {
		return answerKey;
	}

	/**
	 * Set the answer key for the answer.
	 * @param answerKey the answer key.
	 */
	public void setAnswerKey(String answerKey) {
		this.answerKey = answerKey;
	}

	/**
	 * Return the subquestion group id if present.
	 * @return the subquestion group id.
	 */
	public Long getSubquestionGroupId() {
		return subquestionGroupId;
	}

	/**
	 * Set the subquestion group id.
	 * @param subquestionGroupId the subquestion group id to set.
	 */
	public void setSubquestionGroupId(Long subquestionGroupId) {
		this.subquestionGroupId = subquestionGroupId;
	}

	/**
	 * Return the corresponding response set id for the subquestion answers if present.
	 * @return the subquestion response set id if present.
	 */
	public Long getSubquestionResponseSetId() {
		return subquestionResponseSetId;
	}

	/**
	 * Set the subquestion response set id.
	 * @param subquestionResponseSetId the response set if to set.
	 */
	public void setSubquestionResponseSetId(Long subquestionResponseSetId) {
		this.subquestionResponseSetId = subquestionResponseSetId;
	}
}
