<?xml version="1.0" encoding="ISO-8859-1"?>

<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#160;">]>

<xsl:stylesheet version="2.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:java="java"
xmlns:ResourceBundle="java.util.ResourceBundle"
xmlns:FilePathUtilities="org.jharks.workflow.survey.util.FilePathUtilities"
xmlns:Locale="java.util.Locale"
xmlns:String="java.lang.String"
exclude-result-prefixes="java ResourceBundle Locale String FilePathUtilities"
>

<xsl:output method="html" indent="yes"/>
<xsl:param name="resource-bundle"/>
<xsl:param name="db-backed-resource-bundles"/>

  <!-- Locale -->
  <xsl:variable name="language" select="String:new('en')"/>
  <xsl:variable name="locale" select="Locale:new($language)"/>
  <xsl:variable name="i18n" select="FilePathUtilities:getWorkFlowResourceBundleForXsl($resource-bundle, $db-backed-resource-bundles)"/> 
 

<xsl:template match="survey">
 <xsl:variable name="legendName" select="@page" />
 <legend class="jharks-legend"><xsl:value-of select="java:getString($i18n,$legendName)" /></legend>
 <xsl:variable name="validationScriptName"><xsl:value-of select="@page"/>.validation</xsl:variable>
 <xsl:variable name="validationScriptPath" select="FilePathUtilities:getJharksValidationScriptPath($i18n,$validationScriptName)" />
 <xsl:choose>
   <xsl:when test="$validationScriptPath != ''">
     <script type="text/javascript"><xsl:attribute name="src"><xsl:value-of select="$validationScriptPath"/></xsl:attribute></script>
   </xsl:when>
   <xsl:otherwise>
     <xsl:comment>No validation script path found for <xsl:value-of select="$validationScriptName" /></xsl:comment> 
   </xsl:otherwise>
 </xsl:choose>
<!-- Start Questions Section -->
<xsl:for-each select="question">
  <xsl:call-template name="question" />
  <br/>
</xsl:for-each> 
<!-- End Questions Section -->
</xsl:template>

<xsl:template name="question">
  <xsl:param name="name-prefix" required="no" />
  <xsl:param name="element-id" required="no"/>
  <!-- <xsl:variable name="field-name"><xsl:value-of select="$name-prefix" />q<xsl:value-of select="@id" /></xsl:variable> -->
  <xsl:variable name="field-name"><xsl:value-of select="$name-prefix" /><xsl:value-of select="@id" /></xsl:variable>
  <xsl:variable name="field-id">
   <xsl:choose>      
     <xsl:when test="$element-id != ''"><xsl:value-of select="$element-id" /><xsl:value-of select="@id" /></xsl:when>         
     <xsl:otherwise><xsl:value-of select="$name-prefix" /><xsl:value-of select="@id" /></xsl:otherwise>    
   </xsl:choose>
  </xsl:variable>

  <xsl:choose>
    
    <!-- defines the standard text input field. -->
    <xsl:when test="@template='text'">
      <xsl:value-of select="explanation" />
      <xsl:variable name="questionText" select="text" />
      <span class="jharks-question-text"><xsl:value-of select="ResourceBundle:getString($i18n,$questionText)" disable-output-escaping="yes" /></span>
      <xsl:text> </xsl:text>
      <input type="text">
        <xsl:attribute name="name"><xsl:value-of select="$field-name" /></xsl:attribute>
        <xsl:attribute name="id"><xsl:value-of select="$field-id" /></xsl:attribute>
        <xsl:attribute name="value"><xsl:value-of select="./answers/answer" /></xsl:attribute>
      </input>
      <br/>
    </xsl:when>

    <!-- defines the standard textarea input field. -->
    <xsl:when test="@template='textarea'">
      <xsl:value-of select="explanation" />
      <xsl:variable name="questionText" select="text" />
      <span class="jharks-question-text"><xsl:value-of select="ResourceBundle:getString($i18n,$questionText)" disable-output-escaping="yes" /></span><br />
      <textarea>
        <xsl:attribute name="name"><xsl:value-of select="$field-name" /></xsl:attribute>
        <xsl:attribute name="id"><xsl:value-of select="$field-id" /></xsl:attribute>
        <xsl:value-of select="./answers/answer" />
      </textarea>
      <br/>
    </xsl:when>

    <!-- defines the standard dropdown input field. -->
    <xsl:when test="@template='dropdown'">
      <xsl:value-of select="explanation" />
      <xsl:variable name="questionText" select="text" />
      <span class="jharks-question-text"><xsl:value-of select="ResourceBundle:getString($i18n,$questionText)" disable-output-escaping="yes" /></span>
      <xsl:text> </xsl:text>
      <select>
        <xsl:attribute name="name"><xsl:value-of select="$field-name" /></xsl:attribute>
        <xsl:attribute name="id"><xsl:value-of select="$field-id" /></xsl:attribute>
      <xsl:for-each select="answer-choices/answer-choice">
        <option>
          <xsl:attribute name="value"><xsl:value-of select="value" /></xsl:attribute>
          <xsl:if test="@selected='true'"><xsl:attribute name="selected">true</xsl:attribute></xsl:if>
          <xsl:variable name="choiceLabel" select="text" />
          <xsl:value-of select="ResourceBundle:getString($i18n,$choiceLabel)"/>
        </option>
      </xsl:for-each>
      </select>
      <br/>
    </xsl:when>

    <!-- defines the standard checkbox input field. -->
    <xsl:when test="@template='checkbox'">
      <xsl:value-of select="explanation" />
      <xsl:variable name="questionText" select="text" />
      <span class="jharks-question-text"><xsl:value-of select="ResourceBundle:getString($i18n,$questionText)" disable-output-escaping="yes" /></span><br />
      <table border="0" class="jharks-answer-choices">
      <xsl:for-each select="answer-choices/answer-choice" >
        <xsl:variable name="choice-id"><xsl:value-of select="@id" /></xsl:variable>
        <xsl:variable name="choice-alias-id"><xsl:value-of select="@alias-id" /></xsl:variable>
        <tr>
          <td valign="top">
            <input type="checkbox">
              <xsl:attribute name="value"><xsl:value-of select="value" /></xsl:attribute>
              <xsl:attribute name="id"><xsl:value-of select="$field-id" />_<xsl:value-of select="position()" /></xsl:attribute>
              <xsl:attribute name="name"><xsl:value-of select="$field-name" /></xsl:attribute>
              <xsl:if test="@selected='true'">
                <xsl:attribute name="checked">checked</xsl:attribute>
              </xsl:if>
            </input>
          </td>
          <td>
            <xsl:variable name="choiceLabel" select="text" />
            <xsl:value-of select="ResourceBundle:getString($i18n,$choiceLabel)" disable-output-escaping="yes"/>
            
            <xsl:if test="subquestions/question">
            <div>
            <xsl:attribute name="id">SUBQUESTION<xsl:value-of select="$field-id"/>a<xsl:value-of select="$choice-alias-id" /></xsl:attribute>
            <xsl:for-each select="subquestions/question">
              <xsl:call-template name="question">
                <xsl:with-param name="name-prefix"><xsl:value-of select="$field-name" />a<xsl:value-of select="$choice-id" /></xsl:with-param>
                <xsl:with-param name="element-id"><xsl:value-of select="$field-name" />a<xsl:value-of select="$choice-alias-id" /></xsl:with-param>
              </xsl:call-template>
            </xsl:for-each>
            </div>
            <script>
              $(document).ready(function() {
                toggleStatusSUBQUESTIONS<xsl:value-of select="$field-name"/>_<xsl:value-of select="position()" />a<xsl:value-of select="$choice-alias-id" />();
                $('input[id="<xsl:value-of select="$field-name"/>_<xsl:value-of select="position()" />"]').bind('change', function() {
	              toggleStatusSUBQUESTIONS<xsl:value-of select="$field-name"/>_<xsl:value-of select="position()" />a<xsl:value-of select="$choice-alias-id" />();
                });
              });

              function toggleStatusSUBQUESTIONS<xsl:value-of select="$field-name"/>_<xsl:value-of select="position()" />a<xsl:value-of select="$choice-alias-id" />() {
                if ($('input[id="<xsl:value-of select="$field-name"/>_<xsl:value-of select="position()" />"]').is(':checked')) {
                  $('#SUBQUESTION<xsl:value-of select="$field-name"/>a<xsl:value-of select="$choice-alias-id" /> :input').removeAttr('disabled');
                } else {
                  $('#SUBQUESTION<xsl:value-of select="$field-name"/>a<xsl:value-of select="$choice-alias-id" /> :input').attr('disabled', true);
                }
              }
            </script>
            </xsl:if>

          </td>
        </tr>
        <xsl:if test="position()=last()">
        <tr><td colspan="2">
          <!-- if validanguage validation script is present for this page then for radio buttons create
           error message holder at the bottom of the radio button section. -->
          <div class="vdError" style="display: none;">
           <span>
             <xsl:attribute name="id"><xsl:value-of select="$field-id" />_<xsl:value-of select="position()" />_errorMsg</xsl:attribute>
           </span>
          </div>
        </td></tr>
        </xsl:if>
      </xsl:for-each>
      </table>
    </xsl:when>

    <!-- defines the standard radio input field. -->
    <xsl:when test="@template='radio'">
      <xsl:value-of select="explanation" />
      <xsl:variable name="questionText" select="text" />
      <span class="jharks-question-text"><xsl:value-of select="ResourceBundle:getString($i18n,$questionText)" disable-output-escaping="yes" /></span><br />
      <table border="0" class="jharks-answer-choices">
      <xsl:for-each select="answer-choices/answer-choice">
        <xsl:variable name="choice-id"><xsl:value-of select="@id" /></xsl:variable>
        <xsl:variable name="choice-alias-id"><xsl:value-of select="@alias-id" /></xsl:variable>
        <tr>
          <td valign="top">
            <input type="radio">
              <xsl:attribute name="value"><xsl:value-of select="value" /></xsl:attribute>
              <xsl:attribute name="id"><xsl:value-of select="$field-id" /></xsl:attribute>
              <xsl:attribute name="name"><xsl:value-of select="$field-name" /></xsl:attribute>
              <xsl:if test="@selected='true'">
                <xsl:attribute name="checked">checked</xsl:attribute>
              </xsl:if>
            </input>
          </td>
          <td>
            <xsl:variable name="choiceLabel" select="text" />
            <xsl:value-of select="ResourceBundle:getString($i18n,$choiceLabel)" disable-output-escaping="yes"/>
            
            <xsl:if test="subquestions/question">
            <div>
             <xsl:attribute name="id">SUBQUESTION<xsl:value-of select="$field-id"/>a<xsl:value-of select="$choice-alias-id" /></xsl:attribute>
            <xsl:for-each select="subquestions/question">
              <xsl:call-template name="question">
                <xsl:with-param name="name-prefix"><xsl:value-of select="$field-name" />a<xsl:value-of select="$choice-id" /></xsl:with-param>
                <xsl:with-param name="element-id"><xsl:value-of select="$field-name" />a<xsl:value-of select="$choice-alias-id" /></xsl:with-param>
              </xsl:call-template>
            </xsl:for-each>
            </div>
            <script>
              $(document).ready(function() {
                toggleStatusSUBQUESTIONS<xsl:value-of select="$field-name"/>a<xsl:value-of select="$choice-alias-id" />();
                $('input[id="<xsl:value-of select="$field-name"/>"]').bind('change', function() {
	              toggleStatusSUBQUESTIONS<xsl:value-of select="$field-name"/>a<xsl:value-of select="$choice-alias-id" />();
                });
              });

              function toggleStatusSUBQUESTIONS<xsl:value-of select="$field-name"/>a<xsl:value-of select="$choice-alias-id" />() {
                if ($('input[id="<xsl:value-of select="$field-name"/>"][value="<xsl:value-of select="value"/>"]').is(':checked')) {
                  $('#SUBQUESTION<xsl:value-of select="$field-name"/>a<xsl:value-of select="$choice-alias-id" /> :input').removeAttr('disabled');
                } else {
                  $('#SUBQUESTION<xsl:value-of select="$field-name"/>a<xsl:value-of select="$choice-alias-id" /> :input').attr('disabled', true);
                }
              }
            </script>
            </xsl:if>
          </td>
        </tr>
      </xsl:for-each>
      </table>
      <!-- if validanguage validation script is present for this page then for radio buttons create
           error message holder at the bottom of the radio button section. -->
         <div class="vdError" style="display: none;">
           <span>
             <xsl:attribute name="id"><xsl:value-of select="$field-id" />_errorMsg</xsl:attribute>
           </span>
         </div>
    </xsl:when>

    <!-- defines the dropdown-other input field. -->
    <xsl:when test="@template='dropdown-other'">
      <xsl:value-of select="explanation" />
      <xsl:variable name="questionText" select="text" />
      <span class="jharks-question-text"><xsl:value-of select="ResourceBundle:getString($i18n,$questionText)" disable-output-escaping="yes" /></span><br />
      <xsl:text> </xsl:text>
      <select>
        <xsl:attribute name="name"><xsl:value-of select="$field-name" />_1</xsl:attribute>
        <xsl:attribute name="onchange">dropdownChanged('<xsl:value-of select="$field-name" />');</xsl:attribute>
      <option value=""></option>
      <xsl:for-each select="answer-choices/answer-choice">
        <option>
         <xsl:attribute name="value"><xsl:value-of select="value" /></xsl:attribute>
         <xsl:variable name="choiceLabel" select="text" />
         <xsl:value-of select="ResourceBundle:getString($i18n,$choiceLabel)"/>
        </option>
      </xsl:for-each>
      </select>
      or
      <input type="text">
        <xsl:attribute name="name"><xsl:value-of select="$field-name" />_2</xsl:attribute>
        <xsl:attribute name="onchange">otherChanged('<xsl:value-of select="$field-name" />');</xsl:attribute>
      </input>
      <input type="hidden">
        <xsl:attribute name="name"><xsl:value-of select="$field-name" /></xsl:attribute>
        <xsl:attribute name="id"><xsl:value-of select="$field-id" /></xsl:attribute>
      </input>
    </xsl:when>

  </xsl:choose>
</xsl:template>

</xsl:stylesheet>