package org.jharks.workflow.survey.engine.model;

/**
 * Represents an answer choice.
 */
public class AnswerChoice {

    /** The ID. */
    private Long id;

    /** The answer labe. */
    private String answerLabel;
    
    /** The answer key. */
    private String answerKey;

    /** The explanation. */
    private String explanation;
    
    /** The answer choice alias code. */
    private String answerChoiceAliasId;

    /** The subquestions for this answer choice. */
    private QuestionGroup subQuestions;

    /** Default public constructor */
    public AnswerChoice() {
    }
    
    /**
     * Constructore that initializes answer key.
     * @param answerKey the answer key to initialize.
     */
    public AnswerChoice(String answerKey) {
        this.answerKey = answerKey;
    }
    
    /**
     * Constructor that initializes answer key and persistent id for object.
     * @param answerChoiceId the answer choice id.
     * @param answerKey the answer key to initialize.
     */
    public AnswerChoice(Long answerChoiceId, String answerKey) {
    	this.id = answerChoiceId;
    	this.answerKey = answerKey;
    }
    
    /**
     * Sets the ID.
     * 
     * @param id the ID.
     */
    public void setId(long id) {
        this.id = id;
    }

    /**
     * Returns the ID.
     * 
     * @return the ID.
     */
    public Long getId() {
        return id;
    }

    /**
     * Sets the text.
     * 
     * @param text
     *            the text.
     */
    public void setAnswerLabel(String text) {
        this.answerLabel = text;
    }

    /**
     * Returns the text.
     * 
     * @return the text.
     */
    public String getAnswerLabel() {
        return answerLabel;
    }

    /**
     * Sets the value.
     * 
     * @param value the value.
     */
    public void setAnswerKey(String value) {
        this.answerKey = value;
    }

    /**
     * Returns the value.
     * 
     * @return the value.
     */
    public String getAnswerKey() {
        return answerKey;
    }

    /**
     * Sets the explanation.
     * 
     * @param explanation the explanation.
     */
    public void setExplanation(String explanation) {
        this.explanation = explanation;
    }

    /**
     * Returns the explanation.
     * 
     * @return the explanation.
     */
    public String getExplanation() {
        return explanation;
    }

    /**
     * Sets the subquestions for this answer choice.
     * 
     * @param subQuestions
     *            the subquestions.
     */
    public void setSubQuestions(QuestionGroup subQuestions) {
        this.subQuestions = subQuestions;
    }

    /**
     * Returns the subquestions for this answer choice.
     * 
     * @return the subquestions.
     */
    public QuestionGroup getSubQuestions() {
        return subQuestions;
    }
    
    /**
     * Get the answer choice alias.
     * @return the alias for the answer choice.
     */
    public String getAnswerChoiceAliasId() {
		return answerChoiceAliasId;
	}

    /**
     * Set the answer choice alias. The alias can be advantageous in the UI
     * layer for use as a consistent element id in the DOM.
     * @param answerChoiceAlias the alias to set.
     */
	public void setAnswerChoiceAliasId(String answerChoiceAliasId) {
		this.answerChoiceAliasId = answerChoiceAliasId;
	}

	/**
     * Determines if the objects are equal by comparing the value of the 
     * answer keys.
     * 
     * @return true if the answer keys are the same.
     */
    public boolean equals(Object o) {
        
        if (!(o instanceof AnswerChoice)) return false;
        if (this == o) return true;
        AnswerChoice qo = (AnswerChoice) o;
        String key1 = getAnswerKey();
        String key2 = qo.getAnswerKey(); 
        return key1 == null ? key2 == null : key1.equalsIgnoreCase(key2);
    }
    
    /**
     * Returns a hash code for the property.  Bases the hash code on the 
     * answer key strings hash.
     * 
     * @return the hash value.
     */
    public int hashCode() { 
        int result = 17;
        String key = getAnswerKey();
        result = result * 37 + (key == null ? 0 : key.hashCode());
        return result;  
    }
    
    
}
