package org.jharks.workflow.survey.engine.model;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Contains the answers to all of the questions in a single group.
 */
public class GroupAnswers {

    /** Returns the ID of the question group for these answers. */
    private Long questionGroupId;
    
    /** Represents the localized version of the group name. */
    private String localizedGroupLabel;
    
    /** Returns the ID of the answer group for these answers, if known. */
    private Long answerGroupId;
    
    /** The answers, keyed by question ID. */
    private Map<Long, QuestionAnswers> answersByQuestion = new HashMap<Long, QuestionAnswers>();
    
    /** A list of the answers. */
    private List<QuestionAnswers> answers = new ArrayList<QuestionAnswers>();
    
    /**
     * Public constructor.
     * 
     * @param questionGroupId the ID of the question group for these answers.
     */
    public GroupAnswers(Long questionGroupId) {
       this.questionGroupId = questionGroupId;
    }
    
    //TODO: Need to remove.  Put in place in order to get ResponseJdbcDaoImpl to compile.  
    // Need to refactor getResponsesForPageGroup methods that are using constructor GroupAnswers(String group).
    /**
     * Public constructor.
     * 
     * @param questionGroupName for the question group for these answers.  This should already be localized.
     */
    public GroupAnswers(String questionGroupName) {
       this.localizedGroupLabel = questionGroupName;
    }
    
    /**
     * Returns the ID for the question group.
     * 
     * @return the ID for the question group.
     */
    public Long getQuestionGroupId() {
       return questionGroupId;
    }
    
    /**
     * Sets the ID for the answer group.
     * 
     * @param answerGroupId the answer group ID.
     */
    public void setAnswerGroupId(Long answerGroupId) {
       this.answerGroupId = answerGroupId;
    }

    /** 
     * Returns the ID for the answer group, if known.
     * 
     * @return the ID for the answer group, if known.
     */
    public Long getAnswerGroupId() {
       return answerGroupId;
    }
    
    /**
     * Returns the localized group label.
     * 
	 * @return the localized group label
	 */
	public String getLocalizedGroupLabel() {
		return localizedGroupLabel;
	}

	/**
	 * Set the localized version of the group label.
	 * 
	 * @param localizedGroupLabel the localized group label to set.
	 */
	public void setLocalizedGroupLabel(String localizedGroupLabel) {
		this.localizedGroupLabel = localizedGroupLabel;
	}

	/**
     * Adds the answers for a question to the group of answers.
     * 
     * @param qa the answers to a question in the group.
     */
    public void add(QuestionAnswers qa) {
       Question q = qa.getQuestion();
       answersByQuestion.put(q.getQuestionId(), qa);
       answers.add(qa);
    }
    
    /**
     * Returns the answers for the question with the given ID.
     * 
     * @param questionId the question ID.
     * 
     * @return the answers for the question with the given ID, if any.
     */
    public QuestionAnswers getAnswers(Long questionId) {
       return (QuestionAnswers) answersByQuestion.get(questionId);
    }
    
    /**
     * Returns the answers for the given question.
     * 
     * @param questionId the question.
     * 
     * @return the answers for the question, if any.
     */
    public QuestionAnswers getAnswers(Question question) {
       return (QuestionAnswers) answersByQuestion.get(question.getQuestionId());
    }
    
    /**
     * Returns a collection of <CODE>QuestionAnswers</CODE> instances containing
     * the answers to the questions in this group.
     * 
     * @return a collection of <CODE>QuestionAnswers</CODE> instances.
     */
    public Collection<QuestionAnswers> getAnswers() {
       return answers;
    }
    
    
}
