package org.jharks.workflow.survey.engine.model;

import org.apache.commons.collections.comparators.NullComparator;

/**
 * The <object>GroupAnswersKey</object> is a key object that can be used
 * within maps to uniquely identify a <code>GroupAnswers</code> instance
 * stored in a map. 
 * 
 * @author Michael J. Rizzo
 */
public class GroupAnswersKey implements Comparable<GroupAnswersKey> {

	private Long questionGroupId;
	
	private Long answerResponseSetId;
	
	private Integer questionSequence;
	
	/**
	 * Constructor that initializes key appropriately.
	 * @param questionGroupId the question group id associated with the set.
	 * @param answerResponseSetId the answer response set id used to create the answer set.
	 */
	public GroupAnswersKey(Long questionGroupId, Long answerResponseSetId) {
		this.questionGroupId = questionGroupId;
		this.answerResponseSetId = answerResponseSetId;
	}
	
	/**
	 * Determines if the objects are equal by comparing question group id and the answer 
	 * group's response set id.
	 * 
	 * @return true if the question group if and response set id are equal.
	 */
	public boolean equals(Object o) {
		if (o != null && (o.getClass().equals(this.getClass()))) {
		  if (this == o) return true;
		  GroupAnswersKey key = (GroupAnswersKey) o;
		  if (questionGroupId.equals(key.questionGroupId)) return true;
		  //if (!questionGroupId.equals(key.questionGroupId)) return false;
		  //if (answerResponseSetId.equals(key.answerResponseSetId)) return true;
		} 
		return false;
	}
	
	/**
	 * Returns a has code for the key.  Bases the hash code on the quastion group 
	 * id and the the answer response set id.
	 */
	public int hashCode() {
	  int result = 17;
	  result = result * 37 + questionGroupId.hashCode(); //id cannot be null
	  //result = result * 37 + answerResponseSetId.hashCode(); //id cannot be null
	  return result;
	}

	public int compareTo(GroupAnswersKey compareKey) {
		NullComparator nullsafeComparator = new NullComparator(false);
		
		int respDiff = nullsafeComparator.compare(answerResponseSetId, compareKey.answerResponseSetId);
		if (respDiff != 0)
			return respDiff;
		
		int questSeqDiff = nullsafeComparator.compare(questionSequence, compareKey.questionSequence);
		if (questSeqDiff != 0)
			return questSeqDiff;
		
		//All fields are equal
		return 0;
		
	}

	/**
	 * Get the question sequence attribute on the key.
	 * @return the sequence. 
	 */
	public Integer getQuestionSequence() {
		return questionSequence;
	}

	/**
	 * Set the question sequence.
	 * @param questionSequence the sequence to set.
	 */
	public void setQuestionSequence(Integer questionSequence) {
		this.questionSequence = questionSequence;
	}

	
	
	
}
