package org.jharks.workflow.survey.engine.model;

import java.util.LinkedHashMap;
import java.util.Map;


public class GroupBasedAnswerSet {

    private LinkedHashMap<GroupAnswersKey, GroupAnswers> groupResponses;
    
    public GroupBasedAnswerSet() {
        groupResponses = new LinkedHashMap<GroupAnswersKey, GroupAnswers>();
    }
    
    public Map<GroupAnswersKey, GroupAnswers> getGroupResponses() {
        return this.groupResponses;
    }
    
    /**
     * Adds the group answers instance to the GroupBasedAnswerSet.  If an entry already exists
     * for the passed <object>GroupAnswersKey</object>.  The previous entry is replaced.
     * @param groupAnswersKey the key to add to the internal map.
     * @param groupAnswers the <object>GroupAnswers</object> instance to add.
     */
    public void addToGroupBasedAnswerSet(GroupAnswersKey groupAnswersKey, GroupAnswers groupAnswers) {
        groupResponses.put(groupAnswersKey, groupAnswers);
    }
    
    /**
     * Checks to see whether the group based answer set structure already 
     * contains a mapping for the groupAnswersKey.
     * @param groupAnswersKey the key to compare.
     * @return true if the structure already contains a mapping.
     */
    public boolean containsGroupAnswers(GroupAnswersKey groupAnswersKey) {
       return this.groupResponses.containsKey(groupAnswersKey);	
    }
    
    /**
     * Return the <object>GroupAnswers</object> structure for the requested
     * <object>GroupAnswersKey</object>.  Returns null if there is no mapping 
     * present or the key is mapped to a null value.
     * @param groupAnswersKey the key to use for retrieval.
     * @return the found <object>GroupAnswers</object> structure or null if not found.
     */
    public GroupAnswers getGroupAnswers(GroupAnswersKey groupAnswersKey) {
    	return this.groupResponses.get(groupAnswersKey);
    }
}
