/**
 * 
 */
package org.jharks.workflow.survey.engine.model;

/**
 * Represents an answer to a question.  Answers to subquestions for this answer are
 * stored in a <CODE>Map</CODE> that is keyed by the question ID (as a <CODE>Long</CODE> object)
 * for the subquestion.
 * 
 * @author Michael J. Rizzo
 *
 */
public class SurveyAnswer {

    /** The ID of the answer. */
    private Long id;
    
    //TODO: refactor to be named answerKey
    /** The value of the answer. */
    private String value;
    
    /** The localized answer value.  The decoded answer key representation. */
    private String localizedAnswerValue;
    
    /** The subanswers for this answer. */
    private GroupAnswers subAnswers;
    
    /** The answer choice this answer corresponds to. */
    private AnswerChoice answerChoice;
    
    /**
     * Default Constructor
     */
    public SurveyAnswer() {
    }
    
    /**
     * Public constructor.
     * 
     * @param value the value of the answer.
     */
    public SurveyAnswer(String value) {
       this.value = value;
    }
    
    /**
     * Public constructor.
     * 
     * @param id the ID of the answer.
     * @param value the value of the answer.
     */
    public SurveyAnswer(Long id, String value) {
       this.id = id;
       this.value = value;
    }
    
    /**
     * Public constructor
     * 
     * @param id the id of the answer
     * @param value the value (answerKey) of the answer.
     * @param localizedAnswerValue the localized answer value.
     * 
     */
    public SurveyAnswer(Long id, String value, String localizedAnswerValue) {
    	this(id, value);
    	this.localizedAnswerValue = localizedAnswerValue;	
    }
    
    /**
     * Returns the value of the answer.
     * 
     * @return the value of the answer.
     */
    public String getValue() {
       return value;
    }
    
    /**
    * Sets the value of this answer.
    * 
    * @param paramValue the value of the answer.
    */
    public void setValue(String paramValue) {
      this.value = paramValue;
    }
    
    /**
     * Sets the ID for this answer.
     * 
     * @param id the ID for this answer.
     */
    public void setId(long id) {
       this.id = id;
    }
    
    /**
     * Returns the ID for this answer.
     * @return the ID for this answer.
     */
    public long getId() {
       return id;
    }
    
    
    /**
     * Return the localized answer value if set.
     * 
	 * @return the localized answer value if set.
	 */
	public String getLocalizedAnswerValue() {
		return localizedAnswerValue;
	}

	/**
	 * Set the value of the localized answer value.
	 * 
	 * @param localizedAnswerValue the localized answer value to set.
	 */
	public void setLocalizedAnswerValue(String localizedAnswerValue) {
		this.localizedAnswerValue = localizedAnswerValue;
	}

	/**
     * Returns the subanswers for this answer.
     * 
     * @return the subanswers for this answer.
     */
    public GroupAnswers getSubAnswers() {
       return subAnswers;
    }
    
    /**
     * Sets the subanswers for this answer.
     * 
     * @param answers the subanswers for this answer.
     */
    public void setSubAnswers(GroupAnswers answers) {
       this.subAnswers = answers;
    }

    /**
     * Sets the answer choice that this answer corresponds to.
     * 
     * @param answerChoice the answer choice that this answer corresponds to.
     */
    public void setAnswerChoice(AnswerChoice answerChoice) {
       this.answerChoice = answerChoice;
    }

    /**
     * Returns the answer choice that this answer corresponds to.
     * 
     * @return answerChoice the answer choice that this answer corresponds to.
     */
    public AnswerChoice getAnswerChoice() {
       return answerChoice;
    }
    
    
}
