/**
 * 
 */
package org.jharks.workflow.survey.engine.model;


/**
 * The set of statuses for a <object>Survey</object> object.
 * 
 * @author Michael J. Rizzo
 */
public enum SurveyStatus {
     INCOMPLETE(0, "INCOMPLETE"),
     COMPLETE(1, "COMPLETE"),
     FINALIZED(2, "FINALIZED"),
     INVALID(9, "INVALID");
     
	/**
	 * The id of the survey status.
	 */
	private final Integer id;
	
	/**
	 * The description string for the status
	 */
	private final String description;
	
	/**
	 * Enum constructor accepting id and description.
	 * @param id of the survey status.
	 * @param description the description for the survey status.
	 */
	SurveyStatus(Integer id, String description) {
		this.id = id;
		this.description = description;
	}
	
	/**
	 * Return the id of the status.
	 * @return the id of the survey status.
	 */
	public Integer getId() {
		return id;
	}
	
	/**
	 * Return the description string for the Survey status.
	 * @return the description string.
	 */
	public String getDescription() {
		return description;
	}
	
	/**
	 * Allow of lookup of enum member from the the id passed.
	 * @param id the ide to lookup.
	 * @return the enum member, SurveyStatus.
	 */
	public static SurveyStatus valueOf(Integer id) {
		for (SurveyStatus status : SurveyStatus.values()) {
		  if (status.getId().equals(id)) {
			  return status;
		  }
		}
		return null;
	}
}
