package org.jharks.workflow.survey.engine.service;

import java.util.Collection;

import org.jharks.workflow.survey.engine.model.Question;
import org.jharks.workflow.survey.engine.model.QuestionGroupConfiguration;

public interface QuestionManager {
  
  /**
   * Return the system generated question id for the passed question key 
   * (alias text identifier).
   * @param questionKey the question key to look up.
   * @return the question id or null if a question is not found for the passed
   *         key.
   */
  public Long getQuestionId(String questionKey);
  
  /**
   * Returns the set of questions that are mapped to the passed group id.  The
   * group represents any form of page grouping such as a page.
   * @param groupId the group id for which to retrieve mapped questions.
   * @return the set of questions that are contained within the passed group id.
   */
  public Collection<Question> getQuestionsByGroup(String groupId);
  
  /**
   * Returns the question group configuration for the passed group id.
   * @param groupId the group id for which to retrieve the configuration item.
   * @return the configuration object for the passed group id.
   */
  public QuestionGroupConfiguration getQuestionGroupConfiguration(String groupId);
}
