package org.jharks.workflow.survey.engine.service;

import java.sql.SQLException;
import java.util.List;

import org.jharks.workflow.SessionHistory;
import org.jharks.workflow.survey.engine.model.Survey;
import org.jharks.workflow.survey.engine.model.SurveyStatus;

public interface SurveyPersistenceManager {

	/**
	 * Method used to create a new survey.
	 * @param userName the user creating the survey response
	 * @return the created unique identifier for the survey.
	 * @deprecated as of version 0.0.8.  One should use {@link #createSurvey(String, String)}
	 */
	public Long createSurvey(String userName) throws SQLException;
	
	/**
	 * Method used to create a new survey.
	 * @param userName the user creating the survey response.
	 * @param resourceBundleName the resource bundle associated with the survey.
	 * @return the created unique identifier for the survey.
	 * @throws SQLException if error occurs creating survey.
	 */
	public Long createSurvey(String userName, String resourceBundleName) throws SQLException;
	
	/**
	 * Return the survey record for the passed id.
	 * @param surveyId the survey id to retrieve.
	 * @return the found survey record.
	 */
	public Survey getSurveyRecord(Long surveyId);
	
	/**
     * Persists passed state/contents of survey record to the database engine.
     * @param survey the passed survey instance to  persist.
     * @param history a <CODE>SessionHistory</CODE> instance.
     * @return the created <CODE>Survey</CODE> instance.
     * @throws SQLException if error occurs creating or persisting survey.
     */
	public Survey persistSurvey(Survey survey, SessionHistory history) 
	  throws SQLException;
	
	
	/**
     * Iterates through each response set on the <CODE>SessionHistory</CODE>
     * instance and persists to a database.
     * @param survey the survey record containing a valid survey identifier. 
     * @param history the <CODE>SessionHistory</CODE> instance of interest. 
     * @param conn a database connection.
     * @throws SQLException if error occurs persisting any of the 
     * response sets.
     */
	public void saveResponses(Survey survey, SessionHistory history);
	
	/**
	 * Allows a view controller or external system to change the status of
	 * one or more created surveys to the status that was passed.
	 * @param surveyIds a list of survey ids that indicates which
	 * surveys to update.
	 * @return the int representing the number of rows modified/updated.
	 */
	public int changeSurveyStatus(List<Long> surveyIds, SurveyStatus status);
}
