package org.jharks.workflow.survey.engine.service.impl;

import java.util.Collection;

import org.jharks.workflow.survey.engine.cache.DynamicQuestionGroupCache;
import org.jharks.workflow.survey.engine.dao.QuestionDao;
import org.jharks.workflow.survey.engine.model.Question;
import org.jharks.workflow.survey.engine.model.QuestionGroupConfiguration;
import org.jharks.workflow.survey.engine.service.QuestionManager;


/**
 * Service manager for management of questions.
 * 
 * @author Michael J. Rizzo
 */
public class QuestionManagerImpl implements QuestionManager {

    /** The injected or set question dao instance. */
    private QuestionDao questionDao;
    
    /** the injected cache for question group configuration items. */
    private DynamicQuestionGroupCache questionGroupConfigCache;
    
    /** Injection setters */
    public void setQuestionDao(QuestionDao questionDao) {
        this.questionDao = questionDao;
    }
    
    /** 
     * {@inheritDoc}
     */
    public Long getQuestionId(String questionKey) {
        return questionDao.getQuestionId(questionKey);
    }

    /** 
     * {@inheritDoc}
     */
    public Collection<Question> getQuestionsByGroup(String groupId) {
      return questionDao.getQuestionsByGroup(groupId); 
    }
    
    /**
     * {@inheritDoc}
     */
    public QuestionGroupConfiguration getQuestionGroupConfiguration(String groupId) {
        
        QuestionGroupConfiguration config = 
            questionGroupConfigCache.getConfigurationFromCache(groupId);
        
        if (config == null) {
            config = questionDao.getQuestionGroupConfiguration(groupId);
            if (config != null)
              questionGroupConfigCache.putConfigurationInCache(config);
        }
        return config;
    }

    /**
     * Sets the question group configuration item cache.
     * 
     * @param questionGroupConfigCache the question group config cache to set.
     */
    public void setQuestionGroupConfigCache(
            DynamicQuestionGroupCache questionGroupConfigCache) {
        this.questionGroupConfigCache = questionGroupConfigCache;
    }
}
