package org.jharks.workflow.survey.engine.service.impl;

import java.sql.Connection;
import java.util.ResourceBundle;

import javax.servlet.http.HttpServletRequest;

import org.jharks.workflow.ResponseSet;
import org.jharks.workflow.SessionHistory;
import org.jharks.workflow.survey.engine.dao.ResponseDao;
import org.jharks.workflow.survey.engine.model.GroupAnswers;
import org.jharks.workflow.survey.engine.model.GroupBasedAnswerSet;
import org.jharks.workflow.survey.engine.model.Question;
import org.jharks.workflow.survey.engine.model.QuestionAnswers;
import org.jharks.workflow.survey.engine.model.QuestionGroup;
import org.jharks.workflow.survey.engine.service.ResponseManager;
import org.jharks.workflow.survey.engine.web.SurveyAnswerRetriever;


public class ResponseManagerImpl implements ResponseManager {

    private ResponseDao responseDao;
    
    private SurveyAnswerRetriever answerRetriever;
    
    /** Injection setters */
    public void setResponseDao(ResponseDao responseDao) {
        this.responseDao = responseDao;
    }
    
    public void setAnswerRetriever(SurveyAnswerRetriever answerRetriever) {
        this.answerRetriever = answerRetriever;
    }
    
    /**
     * {@inheritDoc}
     */
    public GroupBasedAnswerSet getResponsesSummary(String surveyId) {
        return responseDao.getResponsesSummary(new Long(surveyId));
    }
    
    /**
     * {@inheritDoc}
     */
    public GroupBasedAnswerSet getResponsesSummary(String surveyId,
            boolean localizeAnswerGroups, ResourceBundle bundle) {
        return responseDao.getResponsesSummary(new Long(surveyId),  
                localizeAnswerGroups, bundle);
    }
    
    /**
     * {@inheritDoc}
     */
    public GroupAnswers getResponsesForPageGroup(String pageGroup, SessionHistory sessionHistorySnapshot) {
    	return responseDao.getResponsesForPageGroup(pageGroup, sessionHistorySnapshot);
    }
    
    /**
     * {@inheritDoc}
     */
    public GroupAnswers getResponsesForPageGroup(String pageGroup, Long surveyId) {
        return responseDao.getResponsesForPageGroup(pageGroup, surveyId);        
    }
    
    /**
     *{@inheritDoc}
     */
    public GroupAnswers getResponsesForPageGroup(String pageGroup, Long surveyId, Connection conn) {
       return responseDao.getResponsesForPageGroup(pageGroup, surveyId, conn);   
    }
    
    /**
     * {@inheritDoc}
     */
    public ResponseSet getAnswers(QuestionGroup group, 
            HttpServletRequest request) {
        
        return answerRetriever.getAnswers(group, request);
    }
    
    /**
     * {@inheritDoc}
     */
    public QuestionAnswers getAnswers(Question question, 
            HttpServletRequest request) {
       
        return answerRetriever.getAnswers(question, request); 
    }

}
