/**
 * 
 */
package org.jharks.workflow.survey.engine.service.impl;

import java.io.InputStream;

import org.jharks.workflow.survey.engine.dao.XmlWorkflowDefinitionDao;
import org.jharks.workflow.survey.engine.service.XmlWorkflowDefinitionService;

/**
 * Service interface that defines methods for interaction with xml workflow definitions: persisting xml workflow definition files
 * and for retrieving definitions to be passed to the workflow engine for instantiation of workflows.
 * 
 * @author Michael J. Rizzo
 *
 */
public class XmlWorkflowDefinitionServiceImpl implements
		XmlWorkflowDefinitionService {

	/** Injected instance of xml workflow definition dao. */
	private XmlWorkflowDefinitionDao xmlDefinitionDao;
	
	/**
	 * {@inheritDoc}
	 */
	public InputStream getXmlDefinitionAsStream(Long definitionId) {
		return xmlDefinitionDao.getXmlDefinitionAsStream(definitionId);
	}
	
	/**
	 * {@inheritDoc}
	 */
	public InputStream getXmlDefinitionLatestVersionAsStream(String definitionName) {
		return xmlDefinitionDao.getXmlDefinitionLatestVersionAsStream(definitionName);
	}

	/**
	 * {@inheritDoc}
	 */
	public String getXmlDefinitionAsString(Long definitionId) {
		return xmlDefinitionDao.getXmlDefinitionAsString(definitionId);
	}

	/**
	 * {@inheritDoc}
	 */
	public String getXmlDefinitionLatestVersionAsString(String definitionName) {
		return xmlDefinitionDao.getXmlDefinitionLatestVersionAsString(definitionName);
	}
	
	/**
	 * {@inheritDoc}
	 */
	public void persistXmlDefinition(String definitionName, Long version, InputStream definitionContentStream) {
		xmlDefinitionDao.persistXmlDefinition(definitionName, version, definitionContentStream);
	}

	/**
	 * {@inheritDoc}
	 */
	public Long getDefinitionId(String definitionName, Long definitionVersion) {
		return xmlDefinitionDao.getDefinitionId(definitionName, definitionVersion);
	}

	/**
	 * {@inheritDoc}
	 */
	public Long getDefinitionIdLatestVersion(String definitionName) {
		return xmlDefinitionDao.getDefinitionIdLatestVersion(definitionName);
	}
	
	/**
	 * Retrieve injected workflow definition dao.
	 * @return the dao instance.
	 */
	public XmlWorkflowDefinitionDao getXmlDefinitionDao() {
		return xmlDefinitionDao;
	}

	/**
	 * Setter to be used for injection of dao.
	 * @param xmlDefinitionDao the dao to set.
	 */
	public void setXmlDefinitionDao(XmlWorkflowDefinitionDao xmlDefinitionDao) {
		this.xmlDefinitionDao = xmlDefinitionDao;
	}

}
