package org.jharks.workflow.survey.engine.web;

import javax.servlet.ServletContext;

import org.jharks.workflow.WorkFlowContext;

/**
 * Extension of the base <code>org.jharks.workflow.WorkFlowContext</code> class.  The Web Workflow
 * context adds the reference of the servlet context.  The servlet context can then be used by 
 * workflow action extensions within the web survey engine.  This allows for retrieval of Spring
 * managed beans from within lower Workflow actions.
 * 
 * @author Michael J. Rizzo
 *
 */
public class WorkFlowWebContext extends WorkFlowContext {

	
	/** The reference to the servlet context. */
	protected ServletContext webContext;

	/** Indicator of whether resource bundles are backed by a database repository for this web workflow context. */
	private Boolean resourceBundlesDatabaseBacked = false;
	
	/**
	 * Return the web context.
	 * @return the web context set into workflow context.
	 */
	public ServletContext getWebContext() {
		return webContext;
	}

	/**
	 * Set the web context (i.e. Servlet Context) of the running web application into the 
	 * Workflow context. 
	 * @param webContext the context to set, 
	 */
	public void setWebContext(ServletContext webContext) {
		this.webContext = webContext;
	}

	/**
	 * Indicates whether the resources used for text replacement are backed 
	 * by database repository or not.
	 * @return true if resources are backed by database repository and should
	 *         be retrieved from there for generation of survey pages.
	 */
	public Boolean isResourceBundlesDatabaseBacked() {
		return resourceBundlesDatabaseBacked;
	}

	/**
	 * Set whether the resources are backed by a database or not.
	 * @param resourceBundlesDatabaseBacked the flag indicating whether resources should be 
	 *        backed or not.
	 */
	public void setResourceBundlesDatabaseBacked(
			Boolean resourceBundlesDatabaseBacked) {
		this.resourceBundlesDatabaseBacked = resourceBundlesDatabaseBacked;
	}
	
	/**
	 * Return the the resource database backed indicator as a flag.
	 * @return the indicator as a string.
	 */
	public String getResourceDatabaseBackedAsFlag() {
		return resourceBundlesDatabaseBacked.toString();
	}
}
