package org.jharks.workflow.survey.engine.web.spring.actions;

import java.sql.SQLException;

import org.jharks.workflow.Action;
import org.jharks.workflow.SessionHistory;
import org.jharks.workflow.exception.WorkFlowActionException;
import org.jharks.workflow.survey.engine.model.Survey;
import org.jharks.workflow.survey.engine.model.SurveyStatus;
import org.jharks.workflow.survey.engine.service.SurveyPersistenceManager;
import org.jharks.workflow.survey.engine.web.WorkFlowWebContext;
import org.springframework.web.context.WebApplicationContext;
import org.springframework.web.context.support.WebApplicationContextUtils;

/**
 * The class persists a survey record and marks the status as complete.
 * 
 * @author Michael J. Rizzo
 *
 */
public class PersistSurveyAction extends Action {

	@Override
	public void apply(Object input) throws WorkFlowActionException {

		if (input instanceof WorkFlowWebContext) {
	        WorkFlowWebContext webWorkflowContext = (WorkFlowWebContext) input;   
			
	        SessionHistory sh = webWorkflowContext.getHistory();
	          
	        Survey survey = null;
	        Long surveyKey = sh.getSurveyId();
	        if (surveyKey == null) {
	        	survey = new Survey();
	        } else {
	        	survey = new Survey(surveyKey);
	        }
	        
	        //This action currently marks all records that have reached a persitence
	        //action as COMPLETE.  The state will be transacted into the database within this
	        //action.
	        survey.setStatus(SurveyStatus.COMPLETE);
            
			WebApplicationContext context = WebApplicationContextUtils.getWebApplicationContext(
					webWorkflowContext.getWebContext());
	        	
			SurveyPersistenceManager persistenceService = (SurveyPersistenceManager) 
			  context.getBean("org.jharks.surveyPersistenceManager");
	        
		  try {	
			Survey returnedSurvey = persistenceService.persistSurvey(survey, sh);
			if (returnedSurvey.getSurveyId() != 0)
                sh.setSurveyId(returnedSurvey.getSurveyId());
		  } catch (SQLException sqle) {
			  if ( logger.isDebugEnabled() ) {
                  logger.debug("Error occured persisting survey", sqle);
			  }
			  throw new WorkFlowActionException("Error occurred persisting survey", sqle);
		  }
		} else {
	       throw new ClassCastException("Expecting WorkFlowWebContext Instance.");
		}
	}
}
