package org.jharks.workflow.survey.engine.web.struts;

import java.io.InputStream;
import java.sql.SQLException;
import java.util.Collection;
import java.util.ResourceBundle;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.log4j.Logger;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;
import org.jharks.workflow.ResponseSet;
import org.jharks.workflow.SessionHistory;
import org.jharks.workflow.ViewMapping;
import org.jharks.workflow.WorkFlowContext;
import org.jharks.workflow.WorkFlowKey;
import org.jharks.workflow.WorkFlowManager;
import org.jharks.workflow.WorkFlowTypeRegistry;
import org.jharks.workflow.exception.WorkFlowException;
import org.jharks.workflow.survey.engine.exception.SurveyEngineException;
import org.jharks.workflow.survey.engine.gui.taglib.PresentationConstants;
import org.jharks.workflow.survey.engine.model.GroupAnswers;
import org.jharks.workflow.survey.engine.model.Question;
import org.jharks.workflow.survey.engine.model.QuestionGroup;
import org.jharks.workflow.survey.engine.model.Survey;
import org.jharks.workflow.survey.engine.service.QuestionManager;
import org.jharks.workflow.survey.engine.service.ResponseManager;
import org.jharks.workflow.survey.engine.service.SurveyPersistenceManager;
import org.jharks.workflow.survey.engine.service.XmlWorkflowDefinitionService;
import org.jharks.workflow.survey.engine.web.RequestParameterMap;
import org.jharks.workflow.survey.engine.web.SurveyXmlBuilder;
import org.jharks.workflow.survey.engine.web.WorkFlowWebContext;
import org.jharks.workflow.survey.util.HttpRequestUtilities;
import org.jharks.workflow.survey.util.ViewControllerHelper;
import org.springframework.web.context.WebApplicationContext;
import org.springframework.web.context.support.WebApplicationContextUtils;


/**
 * Non-functional generic action that can be extended by other actions.
 * Provides common survey engine helper methods.
 * 
 * @author Michael J. Rizzo
 *
 */
public abstract class GenericWorkFlowAction extends Action {

	protected static final String BASE_WORKFLOW_MANAGER_CLASS = 
        "org.jharks.workflow.BaseWorkFlowManagerImpl";
	
	private static final Logger LOGGER = Logger.getLogger(
            GenericWorkFlowAction.class);

	/**
	 * Create a new survey reord and return the generated id for the Survey.
	 * @param userId the user id of the active session.
	 * @param resourceBundleName the resource bundle associated with the workflow.
	 * @return the new survey id for the record.
	 * @throws SQLException if error occurs creating new survey record.
	 */
	protected Long createSurveyRecord(String userId, String resourceBundleName) throws SQLException {

		WebApplicationContext context = WebApplicationContextUtils.getWebApplicationContext(
	            this.getServlet().getServletContext());
		
		  SurveyPersistenceManager surveyManager = (SurveyPersistenceManager) context.getBean("org.jharks.surveyPersistenceManager");
		  Long surveyId = surveyManager.createSurvey(userId, resourceBundleName); 
		  return surveyId;
	}
	
	/**
	 * Method used to perform initialization of identified workflow.
	 * @param mapping the struts <object>ActionMapping</object> instance.
	 * @param form the struts <object>ActionForm</object> instance.
	 * @param request the http request instance.
	 * @param response the http response instance.
	 * @param session the http session instance.
	 * @return the name of the view to which the workflow has been initialized.
	 * @throws Exception if error occurs during initialization of the workflow.
	 */
	protected RequestParameterMap initializeWorkflow(ActionMapping mapping,
            ActionForm form,
            HttpServletRequest request,
            HttpServletResponse response, 
            HttpSession session)
            throws Exception {
		
		String userName = request.getParameter(PresentationConstants.USER_NAME);
		  if (HttpRequestUtilities.checkIfParamIsEmpty(userName)) throw new SurveyEngineException("Error initiating survey within jharks survey engine. " +
		  		"[user_name] parameter is not present.");
		  session.setAttribute(PresentationConstants.USER_NAME, userName);

		  String workflowKeyLabel = request.getParameter("workflowKeyLabel");
			if (workflowKeyLabel == null) {
				LOGGER.error("Workflow key label not defined.");
				throw new WorkFlowException("Workflow key for this flow is missing");
			}
		  
		  Long surveyId = null;
		  //If client passed a survey Id on the request object then indicates client wants to start/re-start
		  //a workflow for an existing/persisted survey. 
		  String passedRequestParameterSurveyId =  request.getParameter(PresentationConstants.SURVEY_ID);
		  if (!HttpRequestUtilities.checkIfParamIsEmpty(passedRequestParameterSurveyId)) {
			  surveyId = new Long(passedRequestParameterSurveyId);
		  } else {
			//No survey Id parameter passed so create a new record for the requested workflow.
		    surveyId = createSurveyRecord(userName, workflowKeyLabel);
		  }
		  session.setAttribute(PresentationConstants.SURVEY_ID, surveyId);
		
		String workflowImpl = request.getParameter("workflowImpl");
		if (workflowImpl == null) 
			  workflowImpl = BASE_WORKFLOW_MANAGER_CLASS;
		
		//Indicates whether caller wants to use file resource for workflow defintion or wants it retrieved from 
		//presistent store.
		boolean fileResourceBased = true;
		
		String fileResource = request.getParameter(PresentationConstants.WORKFLOW_FILE_RESOURCE); 
		if (fileResource.equals("false"))
			fileResourceBased = false;
		
		String workflowDefinitionFile = request.getParameter(PresentationConstants.WORKFLOW_DEFINITION_FILE);
		if (workflowDefinitionFile == null && fileResourceBased) {
			LOGGER.error("Workflow definition file not defined.");
			throw new WorkFlowException("Workflow file not defined for this flow");
		}
		
		String startState = null;
    
        startState = (String) request.getParameter(PresentationConstants.STATE);
        
        WorkFlowKey wfKey = new WorkFlowKey(
                workflowKeyLabel, workflowImpl);
    
        WorkFlowManager wfm = null;
    
        if (fileResourceBased) {
          wfm = (WorkFlowManager) 
            WorkFlowTypeRegistry.getInstance(wfKey, "/" + workflowDefinitionFile);
        } else {
          //Get Workflow Definition from persistent repository
        	WebApplicationContext context = WebApplicationContextUtils.getWebApplicationContext(
    	            this.getServlet().getServletContext());
    		
    		  XmlWorkflowDefinitionService xmlWorkflowDefinitionService = (XmlWorkflowDefinitionService) context.getBean("org.jharks.xmlDefintionService");
    		  InputStream workflowDefinitionContent = xmlWorkflowDefinitionService.getXmlDefinitionLatestVersionAsStream(wfKey.getType());
    		  wfm = (WorkFlowManager) 
    		    WorkFlowTypeRegistry.getInstance(wfKey, workflowDefinitionContent, null);
        }
        SessionHistory sesHistory = null;
        
        WorkFlowWebContext workflowWebContext = new WorkFlowWebContext();
        workflowWebContext.setWebContext(this.servlet.getServletContext());
        String saveSnapshots = request.getParameter(PresentationConstants.SAVE_SESSION_HISTORY_PARAM);
          if (!HttpRequestUtilities.checkIfParamIsEmpty(saveSnapshots)) {
            if (saveSnapshots.equalsIgnoreCase("true")) {
              LOGGER.info("SAVE WORKFLOW SNAPSHOTS MODE IS = [ ON ]");
              workflowWebContext.setWorkFlowHistorySnapshot(true);
            }
          }
        sesHistory = workflowWebContext.getHistory();
        
        //Call to method that allows for storing of common attributes to session history 
        //for workflow.
        populateSessionHistory(session, sesHistory);
        
		if (startState != null) 
			wfm.setStartState(startState, true, workflowWebContext);
		
        String viewName = null;
        
        if (workflowWebContext.getActiveView() != null) {
          viewName = workflowWebContext.getActiveView();
        } else {
		  ViewMapping view = wfm.start(workflowWebContext);
		
		  viewName = view.getViewName();    
        }
        
        if (LOGGER.isDebugEnabled())
            LOGGER.debug("Forwarded to view mapping [ " + viewName + " ]");
        
        workflowWebContext.setWorkFlowKey(wfKey);
        
        //Lastly set whether resource bundles for text replacement in the views should 
        //use datbase backed resource bundles or file based resource bundles.
        String workflowResourceBundlesDbBacked = ResourceBundle.getBundle("JharksWorkflowSurveyResources").getString("workflow.resource.bundles.db.backed");
        String paramWorkflowResourcesDbBased = request.getParameter(
        		PresentationConstants.WORKFLOW_RESOURCES_DB_BASED);
        if (!HttpRequestUtilities.checkIfParamIsEmpty(paramWorkflowResourcesDbBased)) {
        	//replace application configuration with passed value
        	workflowResourceBundlesDbBacked = paramWorkflowResourcesDbBased;
        }
        if (workflowResourceBundlesDbBacked.equals("true"))
        	workflowWebContext.setResourceBundlesDatabaseBacked(new Boolean(true));
        
		session.setAttribute(PresentationConstants.WORKFLOW_CONTEXT, workflowWebContext);
		
		RequestParameterMap requestParameterMap = new RequestParameterMap();
		
		requestParameterMap.addParameter(PresentationConstants.PAGE, viewName);
        requestParameterMap.addParameter(PresentationConstants.STATE, workflowWebContext.getActiveState().getName());
        session.setAttribute(PresentationConstants.IS_FORWARD, "true");

        return requestParameterMap;
	}
	
	/**
	 * Resets the active state for a workflow then creates the corresponding
	 * survey page. Commonly used with continuations for web applictions to handle
	 * browser back navigation.
	 * @param page the start page indicated in the request parameter.
	 * @param surveyId the survey record linked to the request.
	 * @param request the http request instance.
	 * @param response the http response instance.
	 * @param session the http session instance.
	 * @param isForward indicate whether moving in forward direction.
	 * @throws Exception if error occurs starting dtsrt state and building start workflow based survey page.
	 */
	protected void processResetState(String page, Long surveyId, HttpServletRequest request,
            HttpServletResponse response, 
            HttpSession session,
            boolean isForward)
            throws Exception {
      
    	/**************************/
    	//Block necessary to handle case where user hits back button.  Need to reset to state based on
		//state parameter presented on the url.
    	WorkFlowContext flowContext = (WorkFlowContext) 
          session.getAttribute(PresentationConstants.WORKFLOW_CONTEXT);
      
        WorkFlowManager wfm = (WorkFlowManager) WorkFlowTypeRegistry.getInstance(
              flowContext.getWorkFlowKey());
      	
        //If navigation in the workflow is a backwards navigation and sessionHistory snapshots mode is on, 
        //retrive snapshot from memory for the back navigation.
        //set retrieved SessionHistory snapshot back to active for workFlowContext.  Repleaces latest/active
        //SessionHistory.
        if (!isForward) {
          if (flowContext.isWorkFlowHistorySnapshots()) {
        	SessionHistory sessionHistorySnapshot = (SessionHistory) flowContext.getSnapshotFromStore(page);
        	//Note: The processResetState is called after the initaliazeWorkflow in this case there 
        	//will not be any snapshot stored yet. If snapshot is null don't reset the workflow's SessionHistory.
        	if (sessionHistorySnapshot != null)
        	  flowContext.setHistory(sessionHistorySnapshot);
          }
        }
        
        //Need state name not page for this function.
    	wfm.setStartState(request.getParameter(PresentationConstants.STATE), false, flowContext);
        /*************************/
        buildSurveyPage(page, surveyId, request, session, isForward);
		
	}
	
	/**
	 * Process a continuation request for a workflow survey request. Get answers from previous page submission,
	 * call workflow mnager to determine next view
	 * @param surveyId the survey id linked to the request.
	 * @param request the http request instance.
	 * @param response the http response instance.
	 * @param session the http session instance.
	 * @throws Exception if error occurs starting dtsrt state and building start workflow based survey page.
	 */
	protected RequestParameterMap processContinuation(Long surveyId, HttpServletRequest request, 
			HttpServletResponse response, 
			HttpSession session) throws Exception  {
		
		RequestParameterMap requestParameterMap = new RequestParameterMap();
		
		WebApplicationContext context = WebApplicationContextUtils.getWebApplicationContext(
	            this.getServlet().getServletContext());
		
		//Not a start a continuation of a flow
  	    ResponseManager responseManager = (ResponseManager) context.getBean("org.jharks.responseManager");
  	  
        QuestionGroup group = (QuestionGroup) session.getAttribute(PresentationConstants.QUESTION_GROUP);
        if (group != null) {
          ResponseSet answers = responseManager.getAnswers(group, request);
          
          WorkFlowContext flowContext = (WorkFlowContext) 
            session.getAttribute(PresentationConstants.WORKFLOW_CONTEXT);
        
          WorkFlowManager wfm = (WorkFlowManager) WorkFlowTypeRegistry.getInstance(
                flowContext.getWorkFlowKey());
          
          SessionHistory workflowSessionHistory = flowContext.getHistory();
          workflowSessionHistory.setProperty(PresentationConstants.QUESTION_GROUP_ID, 
        		  ((QuestionGroup) session.getAttribute(PresentationConstants.QUESTION_GROUP)).getGroupId());
          
          if(flowContext.isAutoPersist()) 
        	  autoPersistSurveyPage(surveyId, flowContext);
          
          ViewMapping vMap = wfm.getNextMapping(answers, flowContext);
          
          ActionMessages messages = new ActionMessages();
          messages.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("confirmation.success"));
          saveMessages(request, messages);
          
          requestParameterMap.addParameter(PresentationConstants.PAGE, vMap.getViewName());
          requestParameterMap.addParameter(PresentationConstants.STATE, flowContext.getActiveState().getName());
          session.setAttribute(PresentationConstants.IS_FORWARD, "true");   
        }
        return requestParameterMap;
	}
	 
	 /**
	  * Method used to store common attributes.
	  * @param session the current application session
	  * @param sh the current workflow session history.
	  * @throws NumberFormatException if error occurs with number conversion.
	  */
	 protected void populateSessionHistory(HttpSession session, 
	            SessionHistory sh) 
	      throws NumberFormatException  {
		 
		  String userName = (String) session.getAttribute(PresentationConstants.USER_NAME);
		  sh.setProperty(PresentationConstants.USER_NAME, userName);
		 
		  sh.setSurveyId((Long) session.getAttribute(PresentationConstants.SURVEY_ID));
	 }
	 
	/**
	 * Reusable method that builds actual content of survey engine page.
	 * Responsible for retrieving question for current page and any possible
	 * answers that are present in the session history for the current page, i.e. QuestionGroup. 
	 *
	 * @param page the page name to be built.
	 * @param surveyRecordId the identifier for the survey id.
	 * @param request the current http request.
	 * @param session the current http application session.
	 * @param isForward indicates whether a forward navigation.
	 * @throws SurveyEngineException if error occurs creating survey page.
	 */
	 protected void buildSurveyPage(String page, Long surveyRecordId, 
				HttpServletRequest request, HttpSession session, boolean isForward) throws SurveyEngineException {
			WebApplicationContext context = WebApplicationContextUtils.getWebApplicationContext(
		              this.getServlet().getServletContext());
		      
		      QuestionManager questionManager = (QuestionManager) context.getBean("org.jharks.questionManager");
		      ResponseManager responseManager = (ResponseManager) context.getBean("org.jharks.responseManager");
			
		      WorkFlowWebContext workFlowContext = (WorkFlowWebContext) session.getAttribute(PresentationConstants.WORKFLOW_CONTEXT);
		      
			  Collection<Question> questions = questionManager.getQuestionsByGroup(
		              page);
		      
			  if (workFlowContext.getActiveState().getViewFilterClassname() != null) {
				  ViewControllerHelper.applyFilter(questions, workFlowContext, 
						  workFlowContext.getActiveState().getViewFilterClassname());
			  } else {
				  LOGGER.info("No view filter specified for active view [ " + workFlowContext.getActiveView() + " ]" );
			  }
			  
		        QuestionGroup group = new QuestionGroup(page);
		        group.addAll(questions);
		        GroupAnswers groupAnswers = null;
		        if (surveyRecordId != null) {
		          
		          if (isForward) {
		            groupAnswers = responseManager.getResponsesForPageGroup(page, surveyRecordId);
		          } else {
		        	  SessionHistory sessionHistory = workFlowContext.getSnapshotFromStore(page);
		        	  groupAnswers = responseManager.getResponsesForPageGroup(page, sessionHistory);
		          }
		        }
		        if (questions != null) { 
		          session.setAttribute(PresentationConstants.QUESTION_GROUP, group);
		          request.setAttribute(PresentationConstants.SURVEY_PAGE_XML_DATA, SurveyXmlBuilder.buildSurveyXml(
		                  page, questions, groupAnswers));
		          request.setAttribute(PresentationConstants.IS_BACK_NAV_ALLOWED, workFlowContext.isBackNavAllowedForActiveView());
		          request.setAttribute(PresentationConstants.QUESTION_GROUP_ID, group.getGroupId());
		        }
	 }
	 
	 /**
	  * Common method that supports page persistence when autoPersist mode is
	  * on within a web based survey backed workflow.
	  * @param surveyId the id of the survey to persist.
	  * @param workflowContext the current workflow context.
	  * @throws SQLException if error occurs peristing the workflow.
	  */
	 protected void autoPersistSurveyPage(Long surveyId, 
				WorkFlowContext workflowContext) throws SQLException {
		 
		 WebApplicationContext context = WebApplicationContextUtils.getWebApplicationContext(
					this.getServlet().getServletContext());
	        	
	     SurveyPersistenceManager persistenceService = (SurveyPersistenceManager) 
			  context.getBean("org.jharks.surveyPersistenceManager");
	     
	     persistenceService.persistSurvey(new Survey(surveyId), workflowContext.getHistory());
	 }
}

