package org.jharks.workflow.survey.util;

import java.io.Serializable;
import java.util.Enumeration;
import java.util.Properties;
import java.util.ResourceBundle;

import org.apache.log4j.Logger;

public class CustomDbResourceBundle extends ResourceBundle implements Serializable {
	
	/** The logger instance for this class. */
	private static final Logger LOGGER = Logger.getLogger(CustomDbResourceBundle.class);
	
    /** The default serial version uid. */
	private static final long serialVersionUID = 1L;

	private String bundleName;
	
	private String variantCode;
	
	private String countryCode;
	
	private String languageCode;
	
	private Properties properties;

	public CustomDbResourceBundle(String baseName, Properties properties){
	      super();
	      this.bundleName = baseName;
	      this.properties = properties;
	}
	
	public CustomDbResourceBundle(String baseName, String countryCode, 
			String languageCode, String variantCode, Properties properties) {
		super();
		this.bundleName = baseName;
		this.countryCode = countryCode;
		this.languageCode = languageCode;
		this.variantCode = variantCode;
		
		this.properties = properties;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	@SuppressWarnings(value = { "unchecked" })
	public Enumeration<String> getKeys() {
		return properties != null ? ((Enumeration<String>) properties
				.propertyNames()) : null;
	}

	@Override
	protected Object handleGetObject(String key) {
		if (parent == null) {
		  if (LOGGER.isDebugEnabled()) {
		    LOGGER.debug("Attempting to retrieve the following resource key from Jharks" +
		  		" parent CustomDbResourcbundle [ " + key + " ]" );	
		  }
		  Object lookupResult = properties.getProperty(key);
		  if (lookupResult == null) {
			if (LOGGER.isDebugEnabled()) {
			    LOGGER.debug("Resource key is missing for [ " + key + " ] , returning key representation.");
			}
			return key;
		  } else {
			return lookupResult;
		  }
		} else {
		  return properties.getProperty(key);
		}
	}
	
	/**
	 * @return the bundleName
	 */
	public String getBundleName() {
		return bundleName;
	}

	/**
	 * @return the variantCode
	 */
	public String getVariantCode() {
		return variantCode;
	}

	/**
	 * @return the countryCode
	 */
	public String getCountryCode() {
		return countryCode;
	}

	/**
	 * @return the languageCode
	 */
	public String getLanguageCode() {
		return languageCode;
	}
	
	/**
	 * Helper method to allow for setting of parent programmatically during
	 * retrievel from cache.
	 * @param bundle the resource bundle on which to set the parent.
	 */
	public void setParentDbBackedBundle(ResourceBundle bundle) {
	    setParent(bundle);
	}

}
