package org.jharks.workflow.survey.util;

import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.apache.log4j.Logger;

/**
 * Class that contains helper methods and useful methods when working with the 
 * jharks reosurce bundles from within the Survey engine.
 * 
 * @author Michael J. Rizzo
 *
 */
public class ResourceUtilities {

	/** The Logger instance for this clas. */
	private static final Logger LOGGER = Logger.getLogger(ResourceUtilities.class);
	
	/**
     * Localizes the encoded group name for user friendly display.
     * @param group the group name to localize.
     * @return the localized string representation of the passed name.
     */
    public static String getLocalizedGroup(String group, ResourceBundle bundle) {
        String groupDecodedValue = null;
        try {
            groupDecodedValue = bundle.getString(group);
         } catch (MissingResourceException mre) {
             if (LOGGER.isDebugEnabled())
             LOGGER.debug("Missing resource exception occurred will use" +
                     "straight value for group [ " + group + " ]");
         }
         if (groupDecodedValue ==  null) { 
             groupDecodedValue = group;
         }
        return groupDecodedValue;
    }
    
    /**
     * Localizes the encoded resource entry for user friendly display.
     * @param resourceEntry the resource entry to localize.
     * @return the localized string representation of the resource entry.
     */
    public static String getLocalizedResourceEntry(String resourceEntry, ResourceBundle bundle) {
        
    	String decodedValue = null;
    	if (resourceEntry == null) return decodedValue;
        try {
            decodedValue = bundle.getString(resourceEntry);
         } catch (MissingResourceException mre) {
             if (LOGGER.isDebugEnabled())
             LOGGER.debug("Missing resource exception occurred will use" +
                     "straight value for group [ " + resourceEntry + " ]");
         }
         if (decodedValue ==  null) { 
             decodedValue = resourceEntry;
         }
        return decodedValue;
    }
	
}
