package org.jharks.workflow.survey.util;

import java.util.Collection;

import org.jharks.workflow.survey.engine.exception.SurveyEngineException;
import org.jharks.workflow.survey.engine.model.Question;
import org.jharks.workflow.survey.engine.model.ViewFilter;
import org.jharks.workflow.survey.engine.web.ViewFilterFactory;
import org.jharks.workflow.survey.engine.web.WorkFlowWebContext;

/**
 * Helper class for implementations functioning as the view controller to
 * the workflow engine.
 * 
 * @author Michael J. Rizzo
 *
 */
public class ViewControllerHelper {

	/**
	 * Builds the view filter and applies the view filter against the collection of 
	 * questions configured by default for the view.
	 * @param questions the questions to apply the filter against.
	 * @param workflowContext the web workflow context.
	 * @param filterClassname the string representing the classname of the filter to instantiate.
	 */
	public static void applyFilter(Collection<Question> questions, WorkFlowWebContext workflowContext, 
			String filterClassname) {
		ViewFilterFactory filterFactory = new ViewFilterFactory();
		try {
		  ViewFilter viewFilter = filterFactory.createViewFilter(filterClassname);
		  viewFilter.filter(questions, workflowContext);
		} catch (Exception e) {
			throw new SurveyEngineException(
					"Error occurred applying view filter. View questions wil not be filtered.", e);
		}
	}
	
	/**
	 * Builds the form field name for the given question.
	 * 
	 * @param prefix the prefix to prepend to the form field names when retrieving answers.
	 * @param question the question to build the form field for.
	 * 
	 * @return the form field name for the question.
	 */
	public static String buildFormFieldName(String prefix, Question question) {
	      if (prefix == null) {
	          return question.getQuestionKey();
	       } else {
	          return prefix + question.getQuestionKey();
	       }
	}
	
}
